# fram-jules

## About

**fram-jules** package is a part of the **FRAM** open-source modelling framework developed by [NVE](https://www.nve.no/). The package contains features for running [open-source power market model JulES](https://github.com/NVE/JulES/).

For package documentation see [fram-jules](https://nve.github.io/fram-jules/). 

For FRAM documentation see [FRAM mainpage](https://nve.github.io/fram).

## Installation

To add the package to your project use:

    pip install fram-jules

With poetry:

    poetry add fram-jules
